.. htsget documentation master file, created by
   sphinx-quickstart on Mon Dec  5 13:29:46 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to htsget's documentation!
==================================

``htsget`` is a Python API and command line interface for the GA4GH Streaming API. It
provides a simple and reliable way to retrieve high-throughput sequencing data from
servers supporting the protocol.

.. toctree::
   :maxdepth: 2

   installation
   quickstart
   api
   cli

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
